orca r3993 - in trunk: . src/orca/scripts/toolkits/Gecko test/keystrokes/firefox
- From: joanied svn gnome org
- To: svn-commits-list gnome org
- Subject: orca r3993 - in trunk: . src/orca/scripts/toolkits/Gecko test/keystrokes/firefox
- Date: Thu, 19 Jun 2008 21:45:21 +0000 (UTC)
Author: joanied
Date: Thu Jun 19 21:45:21 2008
New Revision: 3993
URL: http://svn.gnome.org/viewvc/orca?rev=3993&view=rev
Log:
* src/orca/scripts/toolkits/Gecko/script.py:
test/keystrokes/firefox/html_struct_nav_links.py:
test/keystrokes/firefox/html_role_links.py:
Fix for bug #537839 - Orca does not remember the last position
on a webpage in firefox when using the back command.
Modified:
trunk/ChangeLog
trunk/src/orca/scripts/toolkits/Gecko/script.py
trunk/test/keystrokes/firefox/html_role_links.py
trunk/test/keystrokes/firefox/html_struct_nav_links.py
Modified: trunk/src/orca/scripts/toolkits/Gecko/script.py
==============================================================================
--- trunk/src/orca/scripts/toolkits/Gecko/script.py (original)
+++ trunk/src/orca/scripts/toolkits/Gecko/script.py Thu Jun 19 21:45:21 2008
@@ -2467,7 +2467,7 @@
return
elif not atTop \
and not obj.getState().contains(\
- pyatspi.STATE_EDITABLE):
+ pyatspi.STATE_FOCUSABLE):
self.clearCaretContext()
[obj, characterOffset] = self.getCaretContext()
if not obj:
@@ -2485,16 +2485,17 @@
# For braille, we just show the current line
# containing the caret. For speech, however, we
# will start a Say All operation if the caret is
- # in an uneditable area (e.g., it's not in a text
- # entry area such as Google's search text entry).
- # Otherwise, we'll just speak the line that the
- # caret is on.
+ # in an unfocusable area (e.g., it's not in a text
+ # entry area such as Google's search text entry
+ # or a link that we just returned to by pressing
+ # the back button). Otherwise, we'll just speak the
+ # line that the caret is on.
#
self.updateBraille(obj)
- if obj.getState().contains(pyatspi.STATE_EDITABLE):
+ if obj.getState().contains(pyatspi.STATE_FOCUSABLE):
speech.speakUtterances(\
- self.speechGenerator.getSpeech(obj, True))
+ self.speechGenerator.getSpeech(obj, False))
elif not script_settings.sayAllOnLoad:
self.speakContents(\
self.getLineContentsAtOffset(obj,
Modified: trunk/test/keystrokes/firefox/html_role_links.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_links.py (original)
+++ trunk/test/keystrokes/firefox/html_role_links.py Thu Jun 19 21:45:21 2008
@@ -123,31 +123,10 @@
sequence.append(WaitForDocLoad())
sequence.append(PauseAction(3000))
-sequence.append(KeyComboAction("Down"))
-sequence.append(KeyComboAction("Up"))
-
-########################################################################
-# Press Down Arrow to move to the anchors.html link.
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
- "Line Down to anchors.html",
- ["BRAILLE LINE: 'â anchors.html Link'",
- " VISIBLE: 'â anchors.html Link', cursor=1",
- "SPEECH OUTPUT: 'â anchors.html link'"]))
-
-########################################################################
-# Press Down Arrow to move to the blockquotes.html link. We probably
-# won't get a focus event, so we'll just pause in the next step.
+# Hack to ignore a focus event that will temporarily update braillle
#
-sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
- "Line Down to blockquotes.html",
- ["BRAILLE LINE: 'â blockquotes.html Link'",
- " VISIBLE: 'â blockquotes.html Link', cursor=1",
- "SPEECH OUTPUT: 'â blockquotes.html link'"]))
+sequence.append(KeyComboAction("Up"))
########################################################################
# Press Up Arrow to move to the anchors.html link. We probably won't
Modified: trunk/test/keystrokes/firefox/html_struct_nav_links.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_links.py (original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_links.py Thu Jun 19 21:45:21 2008
@@ -113,26 +113,27 @@
sequence.append(WaitForDocLoad())
########################################################################
# Press U to move to the next unvisited link, anchors.html.
#
sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("u"))
sequence.append(utils.AssertPresentationAction(
- "u to anchors.html link",
- ["BRAILLE LINE: 'â anchors.html Link'",
- " VISIBLE: 'â anchors.html Link', cursor=3",
- "SPEECH OUTPUT: 'anchors.html link'"]))
+ "u to textattributes.html link",
+ ["BRAILLE LINE: 'â textattributes.html Link'",
+ " VISIBLE: 'â textattributes.html Link', cursor=3",
+ "SPEECH OUTPUT: 'textattributes.html link'"]))
########################################################################
-# Press U to move to the next unvisited link, blockquotes.html
+# Press U to move to the next unvisited link, anchors.html
#
sequence.append(utils.StartRecordingAction())
sequence.append(KeyComboAction("u"))
sequence.append(utils.AssertPresentationAction(
- "u to blockquotes.html link",
- ["BRAILLE LINE: 'â blockquotes.html Link'",
- " VISIBLE: 'â blockquotes.html Link', cursor=3",
- "SPEECH OUTPUT: 'blockquotes.html link'"]))
+ "u to anchors.html link",
+ ["BRAILLE LINE: 'â anchors.html Link'",
+ " VISIBLE: 'â anchors.html Link', cursor=3",
+ "SPEECH OUTPUT: 'Wrapping to top.'",
+ "SPEECH OUTPUT: 'anchors.html link'"]))
########################################################################
# Press Return to follow the blockquotes.html link.
@@ -147,17 +148,6 @@
sequence.append(WaitForDocLoad())
########################################################################
-# Press V to move to the next visited link, blockquotes.html.
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("v"))
-sequence.append(utils.AssertPresentationAction(
- "v to blockquotes.html link",
- ["BRAILLE LINE: 'â blockquotes.html Link'",
- " VISIBLE: 'â blockquotes.html Link', cursor=3",
- "SPEECH OUTPUT: 'blockquotes.html link'"]))
-
-########################################################################
# Press V to move to the next visited link, tables.html
#
sequence.append(utils.StartRecordingAction())
@@ -175,10 +165,10 @@
sequence.append(KeyComboAction("v"))
sequence.append(utils.AssertPresentationAction(
"v to blockquotes.html link",
- ["BRAILLE LINE: 'â blockquotes.html Link'",
- " VISIBLE: 'â blockquotes.html Link', cursor=3",
+ ["BRAILLE LINE: 'â anchors.html Link'",
+ " VISIBLE: 'â anchors.html Link', cursor=3",
"SPEECH OUTPUT: 'Wrapping to top.'",
- "SPEECH OUTPUT: 'blockquotes.html link'"]))
+ "SPEECH OUTPUT: 'anchors.html link'"]))
########################################################################
# Press Shift V to move to the previous visited link, tables.html.
[
@@ -113,26 +113,27 @@
sequence.append(WaitForDocLoad())
########################################################################
-# Press U to move to the next unvisited link, anchors.html.
+# Press U to move to the next unvisited link, textattributes.html.
#
sequence.append(utils.StartRecordingAction())
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]